@@ -1,22 +1,9 @@
-// ZenLib::Format::Http::Cookies - Cookies handling
-// Copyright (C) 2008-2011 MediaArea.net SARL, Info@MediaArea.net
-//
-// This software is provided 'as-is', without any express or implied
-// warranty.  In no event will the authors be held liable for any damages
-// arising from the use of this software.
-//
-// Permission is granted to anyone to use this software for any purpose,
-// including commercial applications, and to alter it and redistribute it
-// freely, subject to the following restrictions:
-//
-// 1. The origin of this software must not be misrepresented; you must not
-//    claim that you wrote the original software. If you use this software
-//    in a product, an acknowledgment in the product documentation would be
-//    appreciated but is not required.
-// 2. Altered source versions must be plainly marked as such, and must not be
-//    misrepresented as being the original software.
-// 3. This notice may not be removed or altered from any source distribution.
-//
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a zlib-style license that can
+ *  be found in the License.txt file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
@@ -93,7 +80,7 @@ size_t Cookies::Set(const std::string &Name, const std::string &Value, std::time
 //---------------------------------------------------------------------------
 void Cookies::Create_Lines(std::ostream& Out)
 {
-    for (Cookies::iterator Cookie=begin(); Cookie!=end(); Cookie++)
+    for (Cookies::iterator Cookie=begin(); Cookie!=end(); ++Cookie)
     {
         Out << "Set-Cookie: " << Cookie->first << "=" << Cookie->second.Value;
         if (Cookie->second.Expires!=(time_t)-1)
@@ -115,4 +102,3 @@ void Cookies::Create_Lines(std::ostream& Out)
 } //Namespace
 
 } //Namespace
-
